import React from 'react';
import PropTypes from 'prop-types';
import translate from '../../i18n/translate';

const Title = ({
    className,
    defaultTitle,
    record,
    title,
    translate,
    ...rest
}) => {
    if (!title) {
        return (
            <span className={className} {...rest}>
                {defaultTitle}
            </span>
        );
    }
    if (typeof title === 'string') {
        return (
            <span className={className} {...rest}>
                {translate(title, { _: title })}
            </span>
        );
    }
    return React.cloneElement(title, { className, record, ...rest });
};

Title.propTypes = {
    defaultTitle: PropTypes.string.isRequired,
    className: PropTypes.string,
    record: PropTypes.object,
    translate: PropTypes.func.isRequired,
    title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
};

export default translate(Title);
